==> gatling-core-2.0.0-sources.jar: io/gatling/core/action/builder/PauseBuilder.scala <==
/**
 * Copyright 2011-2014 eBusiness Information, Groupe Excilys (www.ebusinessinformation.fr)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gatling.core.action.builder

import scala.concurrent.duration.Duration

import akka.actor.ActorDSL.actor
import akka.actor.ActorRef
import io.gatling.core.action.Pause
import io.gatling.core.config.Protocols
import io.gatling.core.pause.{ PauseType, Disabled, PauseProtocol }
import io.gatling.core.session.Expression

/**
 * Builder for the 'pause' action.
 *
 * @constructor create a new PauseBuilder
 * @param duration mean duration of the generated pause
 */
class PauseBuilder(duration: Expression[Duration], force: Option[PauseType]) extends ActionBuilder {

  def build(next: ActorRef, protocols: Protocols) = {

    val pauseProtocol = protocols.getProtocol[PauseProtocol].getOrElse(throw new UnsupportedOperationException("Pause protocol hasn't been registered"))

    force.getOrElse(pauseProtocol.pauseType) match {
      case Disabled => next
      case pauseType =>
        val generator = pauseType.generator(duration)
        actor(new Pause(generator, next))
    }
  }

  override def registerDefaultProtocols(protocols: Protocols): Protocols = protocols + PauseProtocol.Default
}

==> gatling-core-2.1.7-sources.jar: io/gatling/core/action/builder/PauseBuilder.scala <==
/**
 * Copyright 2011-2014 eBusiness Information, Groupe Excilys (www.ebusinessinformation.fr)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gatling.core.action.builder

import scala.concurrent.duration.Duration

import akka.actor.ActorDSL.actor
import akka.actor.ActorRef
import io.gatling.core.action.Pause
import io.gatling.core.config.Protocols
import io.gatling.core.pause.{ PauseType, Disabled, PauseProtocol }
import io.gatling.core.session.Expression

/**
 * Builder for the 'pause' action.
 *
 * @constructor create a new PauseBuilder
 * @param duration mean duration of the generated pause
 */
class PauseBuilder(duration: Expression[Duration], force: Option[PauseType]) extends ActionBuilder {

  def build(next: ActorRef, protocols: Protocols) = {

    val pauseProtocol = protocols.getProtocol[PauseProtocol].getOrElse(throw new UnsupportedOperationException("Pause protocol hasn't been registered"))

    force.getOrElse(pauseProtocol.pauseType) match {
      case Disabled => next
      case pauseType =>
        val generator = pauseType.generator(duration)
        actor(actorName("pause"))(new Pause(generator, next))
    }
  }

  override def registerDefaultProtocols(protocols: Protocols): Protocols = protocols + PauseProtocol.Default
}
